==> nextcloud-app-calendar-1%3A2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/bg.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
    "Successfully sent email to " : "Успешно изпратен имейл до",
    "Hello," : "Здравейте, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календара »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрави!",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Календар за Nextcloud",
    "Previous day" : "Вчера",
    "Previous week" : "Миналата седмица",
    "Previous month" : "Предишен месец",
    "Next day" : "Утре",
    "Next week" : "Следваща седмица",
    "Next month" : "Следващия месец",
    "+ New event" : "Ново събитие",
    "Today" : "Днес",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Untitled calendar" : "Нов календар",
    "Edit name" : "Редактирай името",
    "Saving name …" : "Запазване...",
    "Edit color" : "Смени цвета",
    "Saving color …" : "Запазване на цвета ...",
    "Copy private link" : "Копирай скритата връзка",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "Calendar link copied to clipboard." : "Копирано в клипборда",
    "Share link" : "Връзка за споделяне",
    "Publish calendar" : "Публикувай календара",
    "Publishing calendar" : "Публикуване на календара",
    "Copy public link" : "Копирай публичната връзка",
    "Send link to calendar via email" : "Изпрати връзката по имейл",
    "Copied link" : "Копирано!",
    "Delete share link" : "Изтрий споделената връзка",
    "Share with users or groups" : "Сподели с потребители или групи",
    "can edit" : "може да редактира",
    "+ New calendar" : "Нов календар",
    "New calendar" : "Нов календар",
    "Import calendars" : "Импортиране на календари",
    "Filename" : "Име на файла",
    "Calendar to import into" : "Избран календар за внасяне в",
    "Cancel" : "Отказ",
    "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
    "Automatic" : "Автоматично",
    "Show weekends" : "Покажи събота и неделя",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Settings & import" : "Настройки и внасяне",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "On date" : "На дата",
    "Edit time" : "Редакирай времето",
    "Remove reminder" : "Премахни напомнянето",
    "+ Add reminder" : "+ Добави напомняне",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часове"],
    "_day_::_days_" : ["ден","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "No reminders yet" : "Няма напомняния",
    "Busy" : "Зает",
    "Unknown" : "Непознат",
    "Send e-mail" : "Изпрати имейл",
    "All day" : "Цял ден",
    "never" : "никога",
    "after" : "след",
    "first" : "първи",
    "third" : "трети",
    "fourth" : "четвърти",
    "fifth" : "пети",
    "last" : "последен",
    "Repeat" : "Да се повтаря",
    "Repeat every" : "Повтаряй всеки",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "Monday" : "понеделник",
    "Summary" : "Резюме",
    "More" : "Още",
    "Save" : "Запазване",
    "Update" : "Обновяване",
    "Select Date" : "Изберете дата",
    "Personal" : "Лични",
    "Details" : "Подробности",
    "Attendees" : "Участници",
    "Reminders" : "Напомняне",
    "Activity" : "Активност",
    "Close" : "Затвори",
    "Anniversary" : "Годишнина",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Does not repeat" : "Не се повтаря",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Add a description" : "Добави описание",
    "Status" : "Състояние",
    "Confirmed" : "Потвърдено",
    "Tentative" : "Несигурно",
    "Cancelled" : "Отказано",
    "Categories" : "Категории",
    "Add this as a new category" : "Добави като нова категория",
    "Presentation" : "Презентация",
    "Cinema" : "Кино",
    "Mail" : "Поща",
    "Play" : "Пусни",
    "Dentist" : "Зъболекар",
    "Global" : "Глобални"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/bg.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "Предоставеният е-мейл адрес е невалиден",
    "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
    "Successfully sent email to " : "Успешно изпратен имейл до",
    "Hello," : "Здравейте, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календара »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрави!",
    "Upcoming events" : "Предстоящи събития",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Календар за Nextcloud",
    "Previous day" : "Вчера",
    "Previous week" : "Миналата седмица",
    "Previous month" : "Предишен месец",
    "Next day" : "Утре",
    "Next week" : "Следваща седмица",
    "Next month" : "Следващия месец",
    "+ New event" : "Ново събитие",
    "Today" : "Днес",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "List" : "Списък",
    "Untitled calendar" : "Нов календар",
    "Edit name" : "Редактирай името",
    "Saving name …" : "Запазване...",
    "Edit color" : "Смени цвета",
    "Saving color …" : "Запазване на цвета ...",
    "Copy private link" : "Копирай скритата връзка",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "Calendar link copied to clipboard." : "Копирано в клипборда",
    "Share link" : "Връзка за споделяне",
    "Publish calendar" : "Публикувай календара",
    "Publishing calendar" : "Публикуване на календара",
    "Copy public link" : "Копирай публичната връзка",
    "Send link to calendar via email" : "Изпрати връзката по имейл",
    "Copied link" : "Копирано!",
    "Delete share link" : "Изтрий споделената връзка",
    "Share with users or groups" : "Сподели с потребители или групи",
    "can edit" : "може да редактира",
    "+ New calendar" : "Нов календар",
    "New calendar" : "Нов календар",
    "Import calendars" : "Импортиране на календари",
    "Filename" : "Име на файла",
    "Calendar to import into" : "Избран календар за внасяне в",
    "Cancel" : "Отказ",
    "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
    "Automatic" : "Автоматично",
    "Previous period" : "Предишен период",
    "Next period" : "Следващ период",
    "Day view" : "Дневен изглед",
    "Week view" : "Седмичен изглед",
    "Month view" : "Месечен изглед",
    "Actions" : "Действия",
    "Create event" : "Създай събитие",
    "Show weekends" : "Покажи събота и неделя",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Settings & import" : "Настройки и внасяне",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "Audio notification" : "Звуково известие",
    "Other notification" : "Друго известие",
    "On date" : "На дата",
    "Edit time" : "Редакирай времето",
    "Remove reminder" : "Премахни напомнянето",
    "+ Add reminder" : "+ Добави напомняне",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часове"],
    "_day_::_days_" : ["ден","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "No reminders yet" : "Няма напомняния",
    "Busy" : "Зает",
    "Out of office" : "Извън офиса",
    "Unknown" : "Непознат",
    "Send e-mail" : "Изпрати имейл",
    "Event title" : "Заглавие на събитие",
    "All day" : "Цял ден",
    "never" : "никога",
    "after" : "след",
    "_time_::_times_" : ["пъти","пъти"],
    "first" : "първи",
    "third" : "трети",
    "fourth" : "четвърти",
    "fifth" : "пети",
    "last" : "последен",
    "Repeat" : "Да се повтаря",
    "Repeat every" : "Повтаряй всеки",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "Monday" : "понеделник",
    "weekend day" : "Почивен ден",
    "Summary" : "Резюме",
    "More" : "Още",
    "Save" : "Запазване",
    "Update" : "Обновяване",
    "Please enter a valid date" : "Моля да въведете валидна дата",
    "Personal" : "Лични",
    "Create a new event" : "Създай ново събитие",
    "[Today]" : "[днес]",
    "[Tomorrow]" : "[утре]",
    "[Yesterday]" : "[вчера]",
    "Details" : "Подробности",
    "Attendees" : "Участници",
    "Reminders" : "Напомняне",
    "Close" : "Затвори",
    "Anniversary" : "Годишнина",
    "Business" : "Бизнес",
    "Meeting" : "Среща",
    "Phone call" : "Телефонен разговор",
    "Sick day" : "Болничен ден",
    "Travel" : "Пътуване",
    "Vacation" : "Отпуска",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Does not repeat" : "Не се повтаря",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
    "Untitled event" : "Събитие без заглавие",
    "Untitled task" : "Задача без заглавие",
    "next year" : "следващата година",
    "today" : "днес",
    "No events" : "Няма събития",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Add a description" : "Добави описание",
    "Status" : "Състояние",
    "Confirmed" : "Потвърдено",
    "Tentative" : "Несигурно",
    "Categories" : "Категории",
    "Add this as a new category" : "Добави като нова категория",
    "Meditation" : "Медитация",
    "Presentation" : "Презентация",
    "Cinema" : "Кино",
    "Office" : "Офис",
    "Mail" : "Поща",
    "Play" : "Пусни",
    "Basketball" : "Баскетбол",
    "Fishing" : "Риболов",
    "Museum" : "Музей",
    "Park" : "Парк",
    "Doctor" : "Доктор",
    "Dentist" : "Зъболекар",
    "Interview" : "Интервю",
    "Training" : "Обучение",
    "Practice" : "Практика",
    "Sports" : "Спортове",
    "Barber" : "Бръснар",
    "Haircut" : "Подстрижка",
    "Exam" : "Изпит",
    "Fireworks" : "Фойерверки",
    "Marathon" : "Маратон",
    "Video-conference" : "Видео конференция",
    "Conference-call" : "Конферентен разговор",
    "Video-call" : "Видео разговор",
    "Video-chat" : "Видео чат",
    "Video-meeting" : "Видео среща",
    "Conference" : "Конференция",
    "Lecture" : "Лекция",
    "Seminar" : "Семинар",
    "Photograph" : "Фотограф",
    "Shopping" : "Пазаруване",
    "Wine tasting" : "Дегустация на вино",
    "Golf" : "Голф",
    "Dinner" : "Вечеря",
    "Lunch" : "Обяд",
    "Global" : "Глобални"
},
"nplurals=2; plural=(n != 1);");
